#
# spec file for package govulncheck
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           govulncheck
Version:        1.0.1
Release:        bp155.2.1
Summary:        CLI tool to report known CVE vulnerabilities in Go source code and binaries
License:        Apache-2.0 AND BSD-3-Clause
Group:          Development/Languages/Go
URL:            https://github.com/golang/vuln
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.18

%description
govulncheck is a CLI tool to report known vulnerabilities that affect Go code. It uses static analysis of source code or a binary's symbol table to narrow down reports to only those that could affect the application.

By default, govulncheck makes requests to the Go vulnerability database at https://vuln.go.dev. Requests to the vulnerability database contain only module paths, not code or other properties of your program. See https://vuln.go.dev/privacy.html for more. Use the -db flag to specify a different database, which must implement the specification at https://go.dev/security/vuln/database.

%prep
%autosetup -a 1

%build
go build \
   -buildmode=pie \
   ./cmd/govulncheck

%check
# execute the binary as a basic check
./%{name} --help

%install
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Sun Sep 24 2023 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 1.0.1:
  * all: go get golang.org/x/tools@74c255b
  * internal/scan: change the way convert mode works
  * internal/scan: add -version flag
  * internal/vulncheck/internal/gosym: fix typo
  * internal/gosym: update binary mode version parsing
  * internal/scan: refactor to remove redundant code
  * vulncheck/internal/gosym: add support for go versions > 1.20
  * internal/vulncheck/internal/buildinfo: skip failing tests
  * cmd/govulncheck: skip TestCommand in short mode
- _service add setversion to automatically update spec Version
* Tue Sep 12 2023 Lubos Kocman <lubos.kocman@suse.com>
- Correction of license based on legaldb scan
  Add Apache 2.0 for google/go-cmdtest and
  vendor/github.com/google/renameio
* Tue Jul 18 2023 jkowalczyk@suse.com
- Initial package version 1.0.0:
  * internal/scan: print the summary even when there are no findings
  * cmd,internal/govulncheck: change protocol version to v1.0.0
  * cmd,internal: remove experimental reference
  * internal/govulncheck: improve documentation
